@@ -1,4 +1,4 @@
-# $Progeny: main.py,v 1.62 2002/04/09 22:54:40 branden Exp $
+# $Progeny: main.py,v 1.73 2002/06/11 19:08:47 branden Exp $
 
 # Copyright (C) 2001 Progeny Linux Systems, Inc.
 # Authors: Branden Robinson; Jeff Licquia; Eric Gillespie, Jr.
@@ -76,29 +76,17 @@ class Kblang(configlet.Configlet):
         # this is used as a two-way dictionary; the values must be
         # unique as well as the keys
         self.language_list = self.keyboard_list[:]
-        self.language_values = [ "en_US",
-                                 "en_GB",
-                                 "en_CA",
-                                 "fr_FR@euro",
-                                 "fr_CA",
-                                 "de_DE@euro",
-                                 "es_ES@euro",
-                                 "es_MX" ]
-
-        # list of ISO charsets to go with locale settings
-        self.locale_charsets = { "en_US": "ISO-8859-1",
-                                 "en_GB": "ISO-8859-1",
-                                 "en_CA": "ISO-8859-1",
-                                 "fr_FR@euro": "ISO-8859-15",
-                                 "fr_CA": "ISO-8859-1",
-                                 "de_DE@euro": "ISO-8859-15",
-                                 "es_ES@euro": "ISO-8859-15",
-                                 "es_MX": "ISO-8859-1",
-                                 "C": "" }
+        self.language_values = [ "en_US ISO-8859-1",
+                                 "en_GB ISO-8859-1",
+                                 "en_CA ISO-8859-1",
+                                 "fr_FR@euro ISO-8859-15",
+                                 "fr_CA ISO-8859-1",
+                                 "de_DE@euro ISO-8859-15",
+                                 "es_ES@euro ISO-8859-15",
+                                 "es_MX ISO-8859-1" ]
 
         self.language_dict = { }
         for i in range(len(self.language_list)):
-            self.debug("i = %d, self.language_list[i] = %s, self.language_values[i] = %s" % (i, self.language_list[i], self.language_values[i]))
             self.language_dict[self.language_list[i]] = self.language_values[i]
         # POSIX/C is used only for locales, not keyboards
         self.language_list.append("POSIX/C")
@@ -126,6 +114,13 @@ class Kblang(configlet.Configlet):
         self.xkb_variant_list = [ "", "nodeadkeys" ]
         self.xkb_options_list = [ "", "ctrl:nocaps", "ctrl:swapcaps" ]
 
+        self.debug("self.keyboard_list \"%s\"." % (self.keyboard_list,))
+        self.debug("self.language_list \"%s\"." % (self.language_list,))
+        self.debug("self.keyboard_dict \"%s\"." % (self.keyboard_dict,))
+        self.debug("self.language_dict \"%s\"." % (self.language_dict,))
+
+        self.debug("Building self.locale_list.")
+
         # XXX: use everything from the SUPPORTED file until Configlet 2.0 comes
         # out and we can just grab the Choices field; this list is used only by
         # the advanced language combo boxes
@@ -240,7 +235,7 @@ class Kblang(configlet.Configlet):
 
         # initialize the option menus
         newmenu= gtk.GtkMenu()
-        for item in self.language_list:
+        for item in self.keyboard_list:
             menuitem = gtk.GtkMenuItem(item)
             menuitem.show()
             newmenu.append(menuitem)
@@ -248,7 +243,7 @@ class Kblang(configlet.Configlet):
         self.wtree.get_widget("keyboard_optionmenu").set_menu(newmenu)
 
         newmenu= gtk.GtkMenu()
-        for item in self.keyboard_list:
+        for item in self.language_list:
             menuitem = gtk.GtkMenuItem(item)
             menuitem.show()
             newmenu.append(menuitem)
@@ -404,8 +399,14 @@ class Kblang(configlet.Configlet):
         self.debug("self.xkb_options = \"%s\"" % (self.xkb_options,))
 
         self.debconf_data = [ ]
-        self.append_debconf("localeconf/lang",
-                            self.lang + " " + self.locale_charsets[self.lang])
+
+        # if they're using the configlet, they want it to do something
+        self.append_debconf("localeconf/manage_config_with_debconf", "true")
+        self.append_debconf("localeconf/backup_existing_nondebconf_config", "true")
+        self.append_debconf((self.configspace + "/manage_config_with_debconf"), "true")
+        self.append_debconf((self.configspace + "/backup_existing_nondebconf_config"), "true")
+
+        self.append_debconf("localeconf/lang", self.lang)
 
         # only write advanced lang stuff if use_lang is NOT set
         for lc_var in [ "lc_collate",
@@ -414,22 +415,34 @@ class Kblang(configlet.Configlet):
                         "lc_monetary",
                         "lc_numeric",
                         "lc_time" ]:
-            if self.use_lang or self.__dict__[lc_var] == "" or self.__dict__[lc_var] == self.lang:
-                # If the "Use system language" checkbox is set, if the user has
-                # made an empty combo box, or if the user has set the LC_*
-                # variable to be the same as LANG, the LC_* variable is not
-                # overriding LANG.
+            # If the "Use system language" checkbox is set, if the user has
+            # made an empty combo box, or if the user has set the LC_* variable
+            # to be the same as LANG, the LC_* variable is not overriding LANG.
+            #if use_lang or self.__dict__[lc_var] == "" or self.__dict__[lc_var] == self.lang:
+            if self.use_lang:
+                self.debug("setting localeconf/%s to self.lang value: %s" % (lc_var, self.lang))
+                self.append_debconf("localeconf/" + lc_var, self.lang)
+            elif self.__dict__[lc_var] == "":
+                self.debug("self.%s blank; setting localeconf/%s to self.lang value: %s" % (lc_var, lc_var, self.lang))
+                self.append_debconf("localeconf/" + lc_var, self.lang)
+            elif self.__dict__[lc_var] == self.lang:
+                self.debug("self.%s set by user to self.lang value; setting localeconf/%s to self.lang value: %s" % (lc_var, lc_var, self.lang))
                 self.append_debconf("localeconf/" + lc_var, self.lang)
             else:
                 # LC_* variable is overriding LANG
-                self.append_debconf("localeconf/" + lc_var, self.self.__dict__[lc_var] + " " + self.locale_charsets[self.__dict__[lc_var]])
+                self.debug("setting localeconf/%s to %s (overriding self.lang)" % (lc_var, self.__dict__[lc_var]))
+                self.append_debconf("localeconf/" + lc_var, self.__dict__[lc_var])
+                self.debug("adding %s to self.select_lc_vars" % (lc_var.upper(),))
                 self.select_lc_vars.append(lc_var.upper())
 
+        self.debug("self.select_lc_vars = \"%s\"" % (self.select_lc_vars,))
+
         if self.select_lc_vars:
             # covert the list to a comma-delimited string
             delimiter = ", "
             value_string = delimiter.join(self.select_lc_vars)
-            self.append_debconf((self.configspace + "localeconf/select_lc_vars"), value_string)
+            self.debug("setting localeconf/select_lc_vars to %s" % (value_string,))
+            self.append_debconf("localeconf/select_lc_vars", value_string)
 
         self.append_debconf((self.configspace
                              + "/config/inputdevice/keyboard/internal"),
